export default defineNuxtConfig({
  ssr: true,
  future: {
    compatibilityVersion: 4,
  },

  devtools: {
    enabled: true,
  },

  components: {
    global: true,
    dirs: ['~/components'],
  },

  nitro: {
    prerender: {
      routes: [
        '/',
        '/imp',
        '/booking',
        '/flatrate',
        '/references',
        '/contact',
      ]
    }
  },

  css: [
    '~/assets/css/global.css',
    '~/assets/css/header.css',
    '~/assets/css/intro.css',
    '~/assets/css/skills.css',
    '~/assets/css/pricing.css',
    '~/assets/css/customers.css',
    '~/assets/css/contact.css',
    '~/assets/css/services.css',
    '~/assets/css/footer.css',
    '~/assets/css/technology.css',
    '~/assets/css/person.css',
    '~/assets/css/button.css',
    '~/assets/css/spoiler.css',
    '~/assets/css/burger.css',
    '~/assets/css/teaser.css',
    '~/assets/css/project.css',
  ],

  postcss: {
    plugins: {
      'postcss-nesting': { /* plugin options */ },
    },
  },

  routeRules: {
    '/': { prerender: true },
    '/imp': { prerender: true },
    '/booking': { prerender: true },
    '/flatrate': { prerender: true },
    '/references': { prerender: true },
    '/contact': { prerender: true },
  },

  app: {
    pageTransition: {
      name: 'page',
      mode: 'out-in',
    },
    head: {
      htmlAttrs: { lang: 'de' },
    }
  },

  modules: ['@nuxt/icon', '@nuxt/fonts', '@vueuse/nuxt', '@nuxtjs/seo', '@nuxt/content'],

  icon: {
    customCollections: [
      {
        prefix: 'wf',
        dir: './app/assets/icons'
      }
    ],
    provider: 'iconify',
    serverBundle: 'local',
    clientBundle: {
      scan: true,
    },
  },

  site: {
    url: 'https://webfussel.de',
    name: 'webfussel | mehr Fussel im Web by Fiona Urban',
    trailingSlash: true,
  },

  compatibilityDate: '2024-12-04'
})